@@ -111,13 +111,13 @@ class Wrapper(fbchat.Client):
             print("Failed to mark as read")
         self.thread = (thread_id, thread_type)
         self.text = message_object.text
-        self.author = self.utils.getUserName(author_id)
+        self.author = self.utils_getUserName(author_id)
 
         if not self.text: return
 
         if not self.text.startswith(self.Prefix):
             if "onMessage" in self._event_list:
-                self._event_list["onMessage"](author_id=author_id,message_object=message_object,thread_id=thread_id,thread_type=thread_type,ts=ts,**kwargs)
+                t = threading.Thread(target=self._event_list["onMessage"],kwargs={"author_id":author_id,"message_object":message_object,"thread_id":thread_id,"thread_type":thread_type,"ts":ts})
             return
         commandName = self.text.replace(self.Prefix, "", 1).split(" ")[0]
         args = list()
